part of 'value_adjustment_bloc.dart';

class ValueAdjustmentState extends Equatable {
  const ValueAdjustmentState();

  @override
  List<Object> get props => [];
}

class ValueAdjustmentInitial extends ValueAdjustmentState {
  @override
  List<Object> get props => [];
}

class ValueAdjustmentLoaded extends ValueAdjustmentState {
  final List<ValueAdjustments> valueAdjustment;

  const ValueAdjustmentLoaded({required this.valueAdjustment});
  @override
  List<Object> get props => [valueAdjustment];
}

class LoadSpecificValueAdjustment extends ValueAdjustmentState {
  final ValueAdjustments valueAdjustment;

  const LoadSpecificValueAdjustment({required this.valueAdjustment});
  @override
  List<Object> get props => [valueAdjustment];
}

class ShowValueAdjustmentcreen extends ValueAdjustmentState {}

class ValueAdjustmentErrorState extends ValueAdjustmentState {
  const ValueAdjustmentErrorState(this.error);
  final String error;

  @override
  List<Object> get props => [error];
}

class ValueAdjustmentDeletedState extends ValueAdjustmentState {
  final bool success;
  const ValueAdjustmentDeletedState({required this.success});
  @override
  List<Object> get props => [success];
}
